@@ -21,17 +21,24 @@
 
 import glob
 import sys
-from logging import debug, warning
+from logging import debug, info, warning
 
 import marshal
 from nuitka import ModuleRegistry, Options
 from nuitka.importing import ImportCache, Importing, StandardLibrary
-from nuitka.plugins.PluginBase import Plugins
+from nuitka.plugins.Plugins import Plugins
 from nuitka.PythonVersions import python_version
 from nuitka.tree.SourceReading import readSourceCodeFromFilename
 from nuitka.utils import Utils
 
 
+def logRecursion(*args):
+    if Options.isShowInclusion():
+        info(*args)
+    else:
+        debug(*args)
+
+
 def recurseTo(module_package, module_filename, module_relpath, module_kind,
              reason):
     from nuitka.tree import Building
@@ -49,8 +56,8 @@ def recurseTo(module_package, module_filename, module_relpath, module_kind,
         # Check if the module name is known. In order to avoid duplicates,
         # learn the new filename, and continue build if its not.
         if not ImportCache.isImportedModuleByName(module.getFullName()):
-            debug(
-                "Recurse to import '%s' from %s. (%s)",
+            logRecursion(
+                "Recurse to import '%s' from '%s'. (%s)",
                 module.getFullName(),
                 module_relpath,
                 reason
@@ -105,6 +112,7 @@ Cannot recurse to import module '%s' (%s) because code is too complex.""",
                                 ),
                                 is_package    = module.isCompiledPythonPackage(),
                                 user_provided = True,
+                                technical     = False
                             )
 
                             ModuleRegistry.addUncompiledModule(module)
@@ -138,7 +146,6 @@ def decideRecursion(module_filename, module_name, module_package, module_kind):
         module_kind
     )
 
-
     if module_kind == "shlib":
         if Options.isStandaloneMode():
             return True, "Shared library for inclusion."
@@ -236,7 +243,7 @@ def isSameModulePath(path1, path2):
 
 
 def _checkPluginPath(plugin_filename, module_package):
-    # Many branches, for the decision is very complex, pylint: disable=R0912
+    # Many branches, for the decision is very complex
 
     debug(
         "Checking detail plug-in path '%s' '%s':",
@@ -281,6 +288,8 @@ def _checkPluginPath(plugin_filename, module_package):
                 module
             )
 
+            ImportCache.addImportedModule(module)
+
             if module.isCompiledPythonPackage():
                 package_filename = module.getFilename()
 
@@ -292,19 +301,17 @@ def _checkPluginPath(plugin_filename, module_package):
 
                     # Only include it, if it contains actual modules, which will
                     # recurse to this one and find it again.
-                    useful = False
                 else:
                     package_dir = Utils.dirname(package_filename)
 
                     # Real packages will always be included.
-                    useful = True
+                    ModuleRegistry.addRootModule(module)
 
                 debug(
                     "Package directory %s",
                     package_dir
                 )
 
-
                 for sub_path, sub_filename in Utils.listDir(package_dir):
                     if sub_filename in ("__init__.py", "__pycache__"):
                         continue
@@ -314,13 +321,9 @@ def _checkPluginPath(plugin_filename, module_package):
                     if Importing.isPackageDir(sub_path) or \
                        sub_path.endswith(".py"):
                         _checkPluginPath(sub_path, module.getFullName())
-            else:
-                # Modules should always be included.
-                useful = True
 
-            if useful:
+            elif module.isCompiledPythonModule():
                 ModuleRegistry.addRootModule(module)
-                ImportCache.addImportedModule(module)
 
         else:
             warning("Failed to include module from '%s'.", plugin_info[0])
